@@ -30,8 +30,8 @@
 #
 #
 #
-#       This file is version $Revision: 432 $ 
-#                       from $Date: 2011-05-04 16:12:05 -0400 (Wed, 04 May 2011) $
+#       This file is version $Revision: 445 $ 
+#                       from $Date: 2011-08-25 10:43:21 -0400 (Thu, 25 Aug 2011) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -57,7 +57,7 @@ from tkFileDialog import askopenfilename, asksaveasfilename
 from tkMessageBox import askokcancel, showerror, askyesno
 #from ScrolledText import ScrolledText
 from GatoConfiguration import GatoConfiguration
-from Graph import Graph
+import Graph #from Graph import Graph
 from GraphUtil import *
 from GraphDisplay import GraphDisplayToplevel, GraphDisplayFrame
 from GatoUtil import *
@@ -72,6 +72,8 @@ from AnimationHistory import AnimationHistory, AnimationCommand
 # On Windows put a copy of linecache.py included in your Python's 
 # standard lib into the same directory as Gato.py and name it
 # linecacheCopy
+# Same problem exists with py2app on Mac, only py2app is smarter
+# in sabotaging linecache
 try:
     import linecacheCopy as linecache
 except:
@@ -1644,7 +1646,7 @@ class Algorithm:
                 # If no graph is loaded then we still have to show an empty
                 # graph. Otherwise the GraphDisplay is unhappy.
                 self.graphIsDirty = 1
-                self.cleanGraphCopy = Graph()
+                self.cleanGraphCopy = Graph.Graph()
                 return 1
             else:
                 return 0
