@@ -28,8 +28,8 @@
 #
 #
 #
-#       This file is version $Revision: 430 $ 
-#                       from $Date: 2011-04-15 22:25:42 -0400 (Fri, 15 Apr 2011) $
+#       This file is version $Revision: 442 $ 
+#                       from $Date: 2011-07-19 17:05:31 -0400 (Tue, 19 Jul 2011) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -609,9 +609,9 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
     def UpdateVertexAnnotationPosition(self,v):
         pos = self.VertexPosition(v)
         da = self.vertexAnnotation[v]
-        self.canvas.move(da,
-                         pos.x + self.zVertexRadius + 1,
-                         pos.y + self.zVertexRadius + 1)
+        self.canvas.coords(da,
+                           pos.x + self.zVertexRadius + 1,
+                           pos.y + self.zVertexRadius + 1)
         
     def CreateEdgeAnnotation(self,tail,head,annotation,color):
         """ *Internal* Create an edge annotation for (tail,head) on the canvas. 
@@ -632,6 +632,23 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
                                       tag="edgeAnno",
                                       fill=color)
         return da
+
+
+    def UpdateEdgeAnnotationPosition(self, tail, head):
+        """ *Internal* Create an edge annotation for (tail,head) on the canvas. 
+            Position is determined by the embedding specified. """
+        t = self.VertexPosition(tail)  
+        h = self.VertexPosition(head)
+        da = self.edgeAnnotation[(tail,head)]
+        (mX,mY) = orthogonal((h.x - t.x, h.y - t.y))
+        c = self.zVertexRadius
+        x = t.x + .5 * (h.x - t.x) + c * mX
+        y = t.y + .5 * (h.y - t.y) + c * mY
+        # Label to the bottom, to the right
+        self.canvas.coords(da, x, y)
+
+
+        
         
         
     ############################################################################
@@ -872,8 +889,7 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
             
     def SetEdgeAnnotation(self,tail,head,annotation,color="black"):
         """ Add an annotation to (tail,head). Annotations are displayed to the left and
-            the bottom of v and allow to display more info about a vertex. 
-            No error checking!  Does not handle edge deletions/moves !"""	
+            the bottom of v and allow to display more info about a vertex. """	
         if not self.edgeAnnotation.QDefined((tail,head)):
             self.edgeAnnotation[(tail,head)] = self.CreateEdgeAnnotation(tail,head,
                                                                          annotation,
@@ -1141,7 +1157,7 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
             self.G.SetEmbedding(v,x,y)
             
             
-            # move incident edges
+        # move incident edges
         outVertices = self.G.OutNeighbors(v)[:] # Need a copy here
         inVertices = self.G.InNeighbors(v)[:]
         euclidian = self.G.QEuclidian()
@@ -1150,25 +1166,33 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
         t = self.G.GetEmbedding(v)
         for w in outVertices:
             de = self.drawEdges[(v,w)]
+            color = self.canvas.itemconfig(de, "fill")[4]
             self.canvas.delete(de)
             de = self.CreateDrawEdge(v,w)
+            self.canvas.itemconfig( de, fill=color)            
             self.drawEdges[(v,w)] = de
             self.canvas.lower(de,"vertices")
             if euclidian:
                 h = self.G.GetEmbedding(w)
                 self.G.SetEdgeWeight(0,v,w,sqrt((h.x - t.x)**2 + (h.y - t.y)**2))
+            if self.edgeAnnotation.QDefined((v,w)):
+                self.UpdateEdgeAnnotationPosition(v,w)
                 
         # Handle incoming edges
         h = self.G.GetEmbedding(v)
         for w in inVertices:
             de = self.drawEdges[(w,v)]
+            color = self.canvas.itemconfig(de, "fill")[4]
             self.canvas.delete(de)
             de = self.CreateDrawEdge(w,v)
+            self.canvas.itemconfig( de, fill=color)            
             self.drawEdges[(w,v)] = de
             self.canvas.lower(de,"vertices")
             if euclidian:
                 t = self.G.GetEmbedding(w)
-                self.G.SetEdgeWeight(0,w,v,sqrt((h.x - t.x)**2 + (h.y - t.y)**2))                
+                self.G.SetEdgeWeight(0,w,v,sqrt((h.x - t.x)**2 + (h.y - t.y)**2))
+            if self.edgeAnnotation.QDefined((w,v)):
+                self.UpdateEdgeAnnotationPosition(w,v)
         if self.vertexAnnotation.QDefined(v):
             self.UpdateVertexAnnotationPosition(v)
         if self.autoUpdateScrollRegion:
@@ -1288,10 +1312,12 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
             and rotated as to maximize size while still fitting on paper """ 
         bb = self.canvas.bbox("all") # Bounding box of all elements on canvas
         # Give 10 pixels room to breathe
-        x = max(bb[0] - 10,0)
-        y = max(bb[1] - 10,0)
-        width=bb[2] - bb[0] + 10
-        height=bb[3] - bb[1] + 10
+        print "PrintToPSFile", bb
+        padding = 15
+        x = bb[0] - padding
+        y = bb[1] - padding
+        width=bb[2] - bb[0] + 2*padding
+        height=bb[3] - bb[1] + 2*padding
         
         printablePageHeight=280 #m
         printablePageWidth =190 #m
